const fs = require('fs')
const path = require('path')
const targetDir = path.join(process.cwd(), 'dist')
const appConfig = require(path.join(process.cwd(), 'app.config'))
const JSZip = require('jszip')
const zip = new JSZip()

const {offlineCaching, packCompressCode} = appConfig

/**
 * 遍历build后的dist目录下文件
 * @param filePath
 */
const files = []

function getFilesPath(filePath) {
  fs.readdirSync(filePath).forEach(name => {
    const fileDir = path.join(filePath, name)
    if (fs.statSync(fileDir).isFile()) {
      zip.file(fileDir.replace(targetDir, ''), fs.readFileSync(fileDir))
      if (fileDir.indexOf('index.html') === -1) {
        files.push(fileDir.substring(fileDir.indexOf('dist') + 5))
      }
    } else {
      getFilesPath(fileDir)
    }
  })
}

// 是否启用H5离线缓存
if (offlineCaching) {
  getFilesPath(targetDir)
  const __template = `CACHE MANIFEST
  
CACHE:
${files.join('\n')}
`
  fs.writeFileSync(path.join(targetDir, 'sweet.mobile.manifest'), __template)
  console.log('---> 离线缓存 sweet.mobile.manifest 文件生成\n')
}

// 生产-打包build后的代码 生成 app_version.json和app_version.zip文件，用于app壳子h5缓存机制
if (packCompressCode) {
  getFilesPath(targetDir)
  zip.generateAsync({
    type: 'nodebuffer',
    compression: 'DEFLATE',
    compressionOptions: {level: 9}
  }).then(content => {
    fs.writeFile(path.join(targetDir, 'app_version.zip'), content, (err) => {
      if (err) {
        console.log('---> app_version.zip 打包失败\n')
        console.log(err)
        throw err
      } else {
        console.log('---> app_version.zip 打包完成\n')
      }
    })
  })
  const appVersion = {
    "version": new Date().getTime()
  }
  console.log('---> app_version.json 文件生成\n')

  fs.writeFileSync(path.join(targetDir, 'app_version.json'), JSON.stringify(appVersion, null, 2))
}
