/**
 *开发环境koa2 server 配置
 * Created by liuzhengdong on 2018/4/3.
 */
const Koa = require('koa')
const KoaRouter = require('koa-router')()
const webpack = require('webpack')
const path = require('path')
const currentIP = require('ip').address()

const opn = require('opn')
const loggerMiddleware = require('koa-logger')()
const convert = require('koa-convert')
const webpackDevMiddleware = require('koa-webpack-dev-middleware')
const webpackHotMiddleware = require('koa-webpack-hot-middleware')

const appConfig = require(path.join(process.cwd(), 'app.config'))
const config = require('./webpack.config.dev')
const clientCompiler = webpack(config)

const errorMiddleware = require('./koa2-middle/errorMiddleWare')
const fileMiddle = require('./koa2-middle/fileMiddle')
const proxyMiddleware = require('./koa2-middle/proxyMiddleware')

const app = new Koa()
const uri = 'http://' + currentIP + ':' + appConfig.appPort

const devMiddleware = webpackDevMiddleware(clientCompiler, {
  headers: { 'Access-Control-Allow-Origin': '*' },
  stats: {
    colors: true,
    modules: false,
  },
  noInfo: false,
})

// 中间件,一组async函数，generator函数需要convert转换
const middleWares = [
  // 打印请求与响应 日志
  loggerMiddleware,
  // 压缩响应
  require('koa-compress')(),
  // 错误处理
  errorMiddleware,
  // webpack开发中间件
  convert(devMiddleware),
  // webpack热替换中间件
  convert(webpackHotMiddleware(clientCompiler)),
  // 路由
  KoaRouter.middleware(),
  // file中间件
  fileMiddle,
  // 代理中间件
  proxyMiddleware(),
]

middleWares.forEach((middleware) => {
  if (!middleware) {
    return
  }
  app.use(middleware)
})

console.log('> Starting dev server...')

devMiddleware.waitUntilValid(() => {
  console.log('> Listening at ' + uri + '\n')
  opn(uri)
})

// 错误处理
app.on('error', (err) => {
  // console.error('Server error: \n%s\n%s ', err.stack || '')
})

const server = app.listen(appConfig.appPort)

process.on('SIGTERM', () => {
  console.log('Stopping dev server')
  devMiddleware.close()
  server.close(() => {
    process.exit(0)
  })
})
