/**
 * 生产环境webpack配置
 * Created by liuzhengdong on 2018/4/3.
 */
const path = require('path')
const config = require('./webpack.config.base')('prod')
const ExtractCssChunks = require("extract-css-chunks-webpack-plugin")
const OptimizeCssAssetsPlugin = require('optimize-css-assets-webpack-plugin')
const appConfig = require(path.join(process.cwd(), 'app.config'))

config.output.filename = '[name].[chunkhash:8].js'
config.output.chunkFilename = '[id].[chunkhash:8].js'

config.devtool = false
config.mode = 'production'

config.module.rules.push(
  {
    test: /\.css$/,
    use: [ExtractCssChunks.loader, 'css-loader', {
      loader: 'postcss-loader', options: !appConfig.postcssNodeModules ? { exclude: /node_modules/ } : {}
    }],
  },
  {
    test: /\.less$/,
    use: [ExtractCssChunks.loader, 'css-loader', 'postcss-loader', 'less-loader'],
  }
)
config.optimization = {
  runtimeChunk: {
    name: 'sweet-mobile'
  },
  splitChunks: {
    cacheGroups: {
      commons: {
        chunks: 'initial',
        minChunks: 5,
      },
      vendor: {
        chunks: 'all',
        name: 'vendor',
        test: /node_modules/,
        priority: -10,
        reuseExistingChunk: false,
      },
    },
  },
}
config.plugins = (config.plugins || []).concat([
  // 分离css文件
  new ExtractCssChunks({
    filename: '[name].[chunkhash:8].css',
    chunkFilename: '[id].[chunkhash:8].css',
  }),
  new OptimizeCssAssetsPlugin(
    {
      cssProcessorOptions: {
        safe: true,
        // postcss那边已经处理过autoprefixer了，这里把它关掉，否则会导致浏览器前缀兼容范围问题
        autoprefixer: false,
      },
    }
  ),
])

module.exports = config
